@@ -16,6 +16,7 @@ sub call{
     $data->{post_event} = 1 if not defined $data->{post_event};
     $data->{post_event_list} = [qw(login stop state_change input_qrcode new_group new_friend new_group_member lose_group lose_friend lose_group_member)]
         if ref $data->{post_event_list} ne 'ARRAY';
+    $data->{post_stdout} = 0 if not defined $data->{post_stdout};
 
     if(defined $data->{poll_api}){
         $client->on('_mojo_webqq_plugin_openqq_poll_over' => sub{
@@ -29,20 +30,23 @@ sub call{
     $client->on(all_event => sub{
         my($client,$event,@args) =@_;
         return if not first {$event eq $_} @{ $data->{post_event_list} };
-        if(defined $data->{post_api} and ($event eq  'login' or $event eq 'stop' or $event eq 'state_change') ){
+        if($event eq  'login' or $event eq 'stop' or $event eq 'state_change' ){
             my $post_json = {};
             $post_json->{post_type} = "event";
             $post_json->{event} = $event;
             $post_json->{params} = [@args];
-            my($data,$ua,$tx) = $client->http_post($data->{post_api},{ua_connect_timeout=>5,ua_request_timeout=>5,ua_inactivity_timeout=>5,ua_retry_times=>1},json=>$post_json);
-            if($tx->success){
-                $client->debug("插件[".__PACKAGE__ ."]事件[".$event . "](@args)上报成功");
+            $client->stdout_line($client->to_json($post_json)) if $data->{post_stdout};
+            if(defined $data->{post_api}){
+                my($data,$ua,$tx) = $client->http_post($data->{post_api},{ua_connect_timeout=>5,ua_request_timeout=>5,ua_inactivity_timeout=>5,ua_retry_times=>1},json=>$post_json);
+                if($tx->success){
+                    $client->debug("插件[".__PACKAGE__ ."]事件[".$event . "](@args)上报成功");
+                }
+                else{
+                    $client->warn("插件[".__PACKAGE__ . "]事件[".$event."](@args)上报失败:" . $client->encode("utf8",$tx->error->{message}));
+                } 
             }
-            else{
-                $client->warn("插件[".__PACKAGE__ . "]事件[".$event."](@args)上报失败:" . $client->encode("utf8",$tx->error->{message}));
-            } 
         }
-        elsif(defined $data->{post_api} and $event eq 'input_qrcode'){
+        elsif($event eq 'input_qrcode'){
             my ($qrcode_path,$qrcode_data) = @args;
             eval{ $qrcode_data = Mojo::Util::b64_encode($qrcode_data);};
             if($@){
@@ -54,12 +58,15 @@ sub call{
             $post_json->{event} = $event;
             $post_json->{params} = [$qrcode_path,$qrcode_data];
             push @{$post_json->{params} },$client->qrcode_upload_url if defined $client->qrcode_upload_url;
-            my($data,$ua,$tx) = $client->http_post($data->{post_api},json=>$post_json);
-            if($tx->success){
-                $client->debug("插件[".__PACKAGE__ ."]事件[".$event . "]上报成功");
-            }
-            else{
-                $client->warn("插件[".__PACKAGE__ . "]事件[".$event."]上报失败:" . $client->encode("utf8",$tx->error->{message}));
+            $client->stdout_line($client->to_json($post_json)) if $data->{post_stdout};
+            if(defined $data->{post_api}){
+                my($data,$ua,$tx) = $client->http_post($data->{post_api},json=>$post_json);
+                if($tx->success){
+                    $client->debug("插件[".__PACKAGE__ ."]事件[".$event . "]上报成功");
+                }
+                else{
+                    $client->warn("插件[".__PACKAGE__ . "]事件[".$event."]上报失败:" . $client->encode("utf8",$tx->error->{message}));
+                }
             }
         }
         elsif($event =~ /^new_group|lose_group|new_friend|lose_friend|new_discuss|lose_discuss|new_group_member|lose_group_member|new_discuss_member|lose_discuss_member$/){
@@ -73,6 +80,7 @@ sub call{
                 $post_json->{params} = [$args[0]->to_json_hash(0)];
             }
             $check_event_list->append($post_json);
+            $client->stdout_line($client->to_json($post_json)) if $data->{post_stdout};
             $client->http_post($data->{post_api},json=>$post_json,sub{
                 my($data,$ua,$tx) = @_;
                 if($tx->success){
@@ -91,6 +99,7 @@ sub call{
                 params    => [$object->to_json_hash(0),$property,$old,$new],
             };
             $check_event_list->append($post_json);
+            $client->stdout_line($client->to_json($post_json)) if $data->{post_stdout};
             $client->http_post($data->{post_api},json=>$post_json,sub{
                 my($data,$ua,$tx) = @_;
                 if($tx->success){
@@ -109,6 +118,7 @@ sub call{
                 event     => $event,
                 params    => [$event eq 'update_user'?$ref->to_json_hash():map {$_->to_json_hash()} @{$ref}], 
             };
+            $client->stdout_line($client->to_json($post_json)) if $data->{post_stdout};
             $client->http_post($data->{post_api},json=>$post_json,sub{
                 my($data,$ua,$tx) = @_;
                 if($tx->success){
@@ -128,6 +138,7 @@ sub call{
         #delete $post_json->{media_data} if ($post_json->{format} eq "media" and ! $data->{post_media_data});
         $post_json->{post_type} = "receive_message";
         $check_event_list->append($post_json);
+        $client->stdout_line($client->to_json($post_json)) if $data->{post_stdout};
         $client->http_post($data->{post_api},json=>$post_json,sub{
             my($data,$ua,$tx) = @_;
             if($tx->success){
@@ -169,6 +180,7 @@ sub call{
         #delete $post_json->{media_data} if ($post_json->{format} eq "media" and ! $data->{post_media_data});
         $post_json->{post_type} = "send_message";
         $check_event_list->append($post_json);
+        $client->stdout_line($client->to_json($post_json)) if $data->{post_stdout};
         $client->http_post($data->{post_api},json=>$post_json,sub{
             my($data,$ua,$tx) = @_;
             if($tx->success){
@@ -510,11 +522,8 @@ sub call{
     $server->app($server->build_app("Mojo::Webqq::Plugin::Openqq::App"));
     $server->app->secrets("hello world");
     $server->app->log($client->log);
-    if(ref $data eq "ARRAY"){#旧版本兼容性
-        $server->listen([ map { 'http://' . (defined $_->{host}?$_->{host}:"0.0.0.0") .":" . (defined $_->{port}?$_->{port}:5000)} @$data]);
-    }
-    elsif(ref $data eq "HASH" and ref $data->{listen} eq "ARRAY"){
-        my @listen;
+    my @listen;
+    if(ref $data eq "HASH" and ref $data->{listen} eq "ARRAY"){
         for my $listen (@{$data->{listen}}) {
             if($listen->{tls}){
                 my $listen_url = 'https://' . ($listen->{host} // "0.0.0.0") . ":" . ($listen->{port}//443);
@@ -533,8 +542,10 @@ sub call{
                 push @listen,'http://' . ($listen->{host} // "0.0.0.0") . ":" . ($listen->{port}//5000) ;
             }
         }   
-        $server->listen(\@listen) ;
     }
+    else{ @listen = ( 'http://0.0.0.0:5000' ); }
+    $server->listen(\@listen) ;
+    $client->info("插件[Mojo::Webqq::Plugin::Openqq]监听地址: [ " . join(", ",@listen) . " ]");
     $server->start;
 }
 1;
